/* firesokker-common.js
 *
 * Various functions used by the FireSokker extension
 *
 * @author   $Author: meraner $
 * @date     $Date: 2008-08-29 11:40:52 +0200 (Fri, 29 Aug 2008) $
 * @revision $Revision: 86 $
 */

/* Create a new trim function for strings.
 * This function removes all whitespace characters from the end
 * and from the start of a string.
 */

String.prototype.trim = function() { return this.replace(/^\s+|\s+$/g, ""); };

/* Function: fsok_parseCookieVariables
 *
 * Parse the Cookie and return all the variables it contains
 *
 * @param string variable_string    the string containing all the variables
 * @param string separator          the variable separator
 *
 * @return array variables          an associative array, where the variable name is the key
 */
function fsok_parseCookieVariables(variable_string, separator) {
	var variables = new Array();
	var splitted_variables = variable_string.split(separator);
	for (var i = 0; i < splitted_variables.length; i++) {
		var variable_value = splitted_variables[i].split("=");
        if (variable_value.length == 2) {
			variables[variable_value[0].trim()]=unescape(variable_value[1].trim());
        } else {
            if (variable_value.length == 1) {
                variables[variable_value[0].trim()] = "";
            }
        }
	}

	return variables;
}

/* Function: fsok_isNationalTeam
 *
 * Checks if the team ID belongs to a national team.
 *
 * @param int    team_id  The ID of the team *
 * @return bool
 */
function fsok_isNationalTeam(team_id) {
    if (team_id > 100)
        return false;
    var nt_array = new Array (1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,
                     16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,
                     31,32,33,34,35,36,37,38,39,40,41,42,43,44,45,
                     46,47,48,49,50,51,52,53,54,55,56,57,58,59,60,
                     61,62,63,64,65,66,67,68,69,70,71,72,73,75,76,
                     77,78,79,80,81,82,83,84,85,86,87,88,89,90,92,
		             97);

    for (var j = 0; j < nt_array.length; j++) {
        if (team_id == nt_array[j])
            return true;
    }
    return false;
}

/* Function: fsok_alertSlider
 *
 * Show the specified text in an alert-slider.
 *
 * @param obj   doc         the document node
 * @param obj   text        the text message
 *
 * @return void
 */

function fsok_alertSlider(doc,text) {
	try {
		var alertsService = Components.classes["@mozilla.org/alerts-service;1"].getService(Components.interfaces.nsIAlertsService);
		var img = "chrome://firesokker/content/icons/firesokker-32x32.png";
		var title = "FireSokker";
		var clickable = false;
		alertsService.showAlertNotification(img, title, text, clickable, "", null);
	} catch (e) {
		fsok_log(e,doc);
	}
}

/* Function: fsok_callFunction
 *
 * This function will execute a given function using the document
 * node as function parameter
 *
 * @param  obj  func  The function to be executed
 * @param  obj  doc   The context (document node)
 *
 * @return void
 */
function fsok_callFunction(func,doc) {
	try {
		func(doc);
	} catch (e) {
		fsok_log(e,doc);
	}
	return true;
}

/* Function: fsok_log
 *
 * If debug mode is enabled write a message to the log console
 *
 * @param  string  msg  The message that should be written to the log console
 * @param  obj     doc  The document node where the function was called
 *
 * @return void
 */
function fsok_log(msg,doc) {
	if (fsok_prefs.getBoolPref("debug_mode")) {
		fsok_log_console.logStringMessage("FireSokker::DEBUG  "+doc.location.pathname+"  "+msg);
	}
}

/* Function: fsok_setStatusBarText
 *
 * Write a message to the FireSokker status bar panel.
 *
 * @param  string  label   The message that should be written to the status bar
 * @param  string  tooltip The message that should be written to the status bar tooltip
 *
 * @return void
 */
function fsok_setStatusBarText(label,tooltip) {
	var fsok_panel = document.getElementById('firesokker-status-panel');
	fsok_panel.label = label;
	fsok_panel.tooltipText = tooltip;
}

/* Function: fsok_enable
 *
 * Enable FireSokker if it is disabled, otherwise disable it;
 *
 * @param  obj  event   The event that triggered the function call
 *
 * @return void
 */
function fsok_enable(event) {
	if (fsok_prefs.getBoolPref("enabled")) {
		fsok_prefs.setBoolPref("enabled", false);
	} else {
		fsok_prefs.setBoolPref("enabled", true);
	}
}

/* Function: formatNumber
 *
 * Number formatting function
 * permission to use this function is granted provided
 * that this copyright notice is retained intact
 *
 * @copyright Stephen Chapman 24th March 2006, 10th February 2007
 *
 * @param  string  num   The number
 * @param  int     dec   Number of decimals
 * @param  char    thou  Thousands separator
 * @param  char    pnt   Comma symbol
 * @param  char    curr1 Currency symbol prefix
 * @param  char    curr2 Currency symbol suffix
 * @param  char    n1    Prefix for negative numbers
 * @param  char    n2    Suffix for negative numbers
 *
 * @return void
 */
function formatNumber(num,dec,thou,pnt,curr1,curr2,n1,n2) {
	var x = Math.round(num * Math.pow(10,dec));
	if (x >= 0)
		n1 = n2 = '';
	var y = (''+Math.abs(x)).split('');
	var z = y.length - dec;
	if (z < 0)
		z--;
	for (var i = z; i < 0; i++)
		y.unshift('0');
	y.splice(z, 0, pnt);
	if(y[0] == pnt)
		y.unshift('0');
	while (z > 3) {
		z-=3;
		y.splice(z,0,thou);
	}
	var r = curr1+n1+y.join('')+n2+curr2;
	return r;
}

/* Function: fsok_getTextOnly
 *
 * This function loops through all child-nodes of
 * the specified node and returns the cleaned up text
 * content of the node
 *
 * @copyright dirty_leo & SwatjeLwd
 *
 * @param obj  node  The element
 *
 * @return string
 */
function fsok_getTextOnly(node) {

  var node_count = node.childNodes.length;
  var node_text = "";
  var child_node;

  for (var i=0; i<node_count; i++) {
    child_node = node.childNodes[i];
    if (child_node.childNodes.length > 0) {
      node_text = node_text + fsok_getTextOnly(child_node);
    } else {
      if (child_node.nodeType == 3) {
        node_text = node_text + child_node.nodeValue;
      }
    }
  }

  return node_text;
}